MethodChannelInappstoryPlugin class
An implementation of InappstoryPluginPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- InappstoryPluginPlatform
- MethodChannelInappstoryPlugin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inappstorySdkModuleHostApi → InappstorySdkModuleHostApi
-
final
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String?> -
override
-
initWith(
String apiKey, String userId, {bool anonymous = false, String? userSign, String? languageCode, String? languageRegion, String? cacheSize}) → FutureOr< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited