InAppStorySdkModule class abstract
This is an abstract class that defines the interface for initializing the InAppStory SDK module.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
initWith(
String apiKey, String userId, {bool anonymous, String? languageCode, String? languageRegion, String? userSign, String? cacheSize, List< String> ? tags}) → FutureOr<void> -
isInitialized(
) → FutureOr< bool> - Returns whether the native SDK has already been initialized.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited